.. pysoundanalyser documentation master file, created by
   sphinx-quickstart on Sun Jun  4 21:54:36 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pysoundanalyser's documentation!
===========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   installation
   user_interface

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
